==> forestry_1.12.2-5.8.0.261-sources.jar: forestry/book/gui/buttons/GuiButtonPage.java <==
package forestry.book.gui.buttons;

import javax.annotation.Nullable;

import net.minecraft.client.Minecraft;
import net.minecraft.client.gui.GuiButton;
import net.minecraft.client.renderer.GlStateManager;
import net.minecraft.client.renderer.texture.TextureManager;

import forestry.book.gui.GuiForesterBook;
import forestry.core.gui.tooltips.IToolTipProvider;
import forestry.core.gui.tooltips.ToolTip;

public class GuiButtonPage extends GuiButton implements IToolTipProvider {
	public boolean left;

	public GuiButtonPage(int buttonId, int x, int y, boolean left) {
		super(buttonId, x, y, 18, 10, "");
		this.left = left;
	}

	@Override
	public void func_191745_a(Minecraft mc, int mouseX, int mouseY, float partialTicks) {
		if (field_146125_m) {
			this.field_146123_n = mouseX >= this.field_146128_h && mouseY >= this.field_146129_i && mouseX < this.field_146128_h + this.field_146120_f && mouseY < this.field_146129_i + this.field_146121_g;

			TextureManager manager = mc.field_71446_o;
			manager.func_110577_a(GuiForesterBook.TEXTURE);
			GlStateManager.func_179131_c(1.0F, 1.0F, 1.0F, 1.0F);
			GlStateManager.func_179141_d();
			GlStateManager.func_179084_k();
			func_73729_b(field_146128_h, field_146129_i, field_146123_n ? 18 : 0, 181 + (left ? 10 : 0), 18, 10);
			GlStateManager.func_179147_l();
			GlStateManager.func_179118_c();
		}
	}

	@Nullable
	@Override
	public ToolTip getToolTip(int mouseX, int mouseY) {
		return null;
	}

	@Override
	public boolean isToolTipVisible() {
		return false;
	}

	@Override
	public boolean isMouseOver(int mouseX, int mouseY) {
		return false;
	}
}

==> forestry_1.12.2-5.8.0.270-sources.jar: forestry/book/gui/buttons/GuiButtonPage.java <==
package forestry.book.gui.buttons;

import javax.annotation.Nullable;

import net.minecraft.client.Minecraft;
import net.minecraft.client.gui.GuiButton;
import net.minecraft.client.renderer.GlStateManager;
import net.minecraft.client.renderer.texture.TextureManager;

import net.minecraftforge.fml.relauncher.Side;
import net.minecraftforge.fml.relauncher.SideOnly;

import forestry.book.gui.GuiForesterBook;
import forestry.core.gui.tooltips.IToolTipProvider;
import forestry.core.gui.tooltips.ToolTip;

@SideOnly(Side.CLIENT)
public class GuiButtonPage extends GuiButton implements IToolTipProvider {
	public boolean left;

	public GuiButtonPage(int buttonId, int x, int y, boolean left) {
		super(buttonId, x, y, 18, 10, "");
		this.left = left;
	}

	@Override
	public void func_191745_a(Minecraft mc, int mouseX, int mouseY, float partialTicks) {
		if (field_146125_m) {
			this.field_146123_n = mouseX >= this.field_146128_h && mouseY >= this.field_146129_i && mouseX < this.field_146128_h + this.field_146120_f && mouseY < this.field_146129_i + this.field_146121_g;

			TextureManager manager = mc.field_71446_o;
			manager.func_110577_a(GuiForesterBook.TEXTURE);
			GlStateManager.func_179131_c(1.0F, 1.0F, 1.0F, 1.0F);
			GlStateManager.func_179141_d();
			GlStateManager.func_179084_k();
			func_73729_b(field_146128_h, field_146129_i, field_146123_n ? 18 : 0, 181 + (left ? 10 : 0), 18, 10);
			GlStateManager.func_179147_l();
			GlStateManager.func_179118_c();
		}
	}

	@Nullable
	@Override
	public ToolTip getToolTip(int mouseX, int mouseY) {
		return null;
	}

	@Override
	public boolean isToolTipVisible() {
		return false;
	}

	@Override
	public boolean isMouseOver(int mouseX, int mouseY) {
		return false;
	}
}
